@@ -30,7 +30,7 @@ roc_calc <- function(R) {
 #' ggs_rocplot(ggs(s.binary, family="mu"), outcome=y.binary)
 ggs_rocplot <- function(D, outcome, fully_bayesian=FALSE) {
   # Create a single object that stores the predicted 'value' and the observed 'Outcome'
-  D.observed <- dplyr::tbl_df(data.frame(Observed=outcome, Parameter=unique(D$Parameter)))
+  D.observed <- dplyr::as_tibble(data.frame(Observed=outcome, Parameter=unique(D$Parameter)))
   # Work with the full posterior or with the expected medians, to economize memory
   if (fully_bayesian) {
     D.predicted <- D
@@ -44,7 +44,7 @@ ggs_rocplot <- function(D, outcome, fully_bayesian=FALSE) {
   # Compute the roc curve using the roc_calc function
   roc.df <- dplyr::bind_cols(roc.df, roc_calc(dplyr::select(roc.df, value, Observed)))
   # Sort it to be sure that the figure is plotted nicely
-  roc.df <- dplyr::tbl_df(roc.df) %>%
+  roc.df <- dplyr::as_tibble(roc.df) %>%
     dplyr::arrange(Sensitivity, Specificity)
   # Plot differently if it's a fully Bayesian figure or not
   if (fully_bayesian) {
